<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\127\x6f\162\144\x50\x72\145\x73\163"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\x6f\x64\x65\x6a\163"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\164\x61\x74\151\x63"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\x79\164\150\x6f\x6e"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\122\x65\166\x65\x72\163\x65\120\162\157\170\171"; private const VARNISH_CACHE_SERVER = "\x31\x32\x37\56\x30\x2e\60\56\x31\x3a\66\60\70\61"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\x46\123\x5f\115\105\x54\x48\x4f\x44" => ["\166\141\x6c\165\145" => "\144\151\162\145\x63\x74", "\x72\x61\167" => false], "\127\120\137\x44\105\x42\x55\x47\x5f\x44\111\123\x50\x4c\101\x59" => ["\x76\x61\x6c\165\145" => "\x66\141\154\x73\145", "\162\x61\167" => true], "\127\120\137\x44\105\x42\x55\x47\137\114\117\x47" => ["\166\141\154\165\x65" => "\164\162\165\x65", "\x72\141\x77" => true], "\x43\x4f\116\x43\x41\124\105\x4e\101\124\x45\137\123\x43\122\x49\120\124\x53" => ["\x76\x61\154\x75\145" => "\146\141\x6c\163\x65", "\x72\x61\x77" => true], "\101\125\124\117\x53\101\x56\x45\137\x49\116\x54\105\122\x56\x41\114" => ["\166\141\x6c\x75\x65" => 600, "\162\x61\167" => true], "\127\120\137\120\117\123\x54\x5f\x52\x45\126\x49\x53\111\117\116\x53" => ["\x76\141\154\x75\x65" => 5, "\x72\x61\167" => true], "\x45\x4d\x50\124\x59\x5f\x54\122\x41\123\x48\137\x44\x41\x59\123" => ["\x76\141\x6c\x75\x65" => 21, "\162\x61\x77" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\x50\x5f\x41\114\114\x4f\127\137\x4d\x55\x4c\x54\111\x53\x49\124\x45" => ["\x76\x61\x6c\165\145" => "\164\162\x75\x65", "\x72\x61\167" => true], "\115\125\114\124\x49\123\x49\124\105" => ["\x76\141\154\x75\x65" => "\164\x72\165\145", "\x72\141\x77" => true], "\123\125\x42\x44\117\x4d\x41\x49\x4e\137\111\x4e\123\124\x41\x4c\x4c" => ["\166\141\x6c\x75\145" => "\146\x61\154\x73\x65", "\162\x61\x77" => true], "\x44\117\x4d\101\x49\x4e\137\x43\125\x52\x52\105\116\124\137\123\x49\124\x45" => ["\x76\x61\x6c\x75\x65" => '', "\162\x61\167" => false], "\120\x41\124\x48\x5f\103\x55\x52\x52\x45\x4e\x54\137\x53\111\124\105" => ["\x76\x61\154\x75\x65" => "\x2f", "\x72\x61\x77" => false], "\x53\x49\124\105\x5f\x49\104\x5f\103\x55\122\122\105\x4e\124\x5f\123\x49\124\105" => ["\x76\141\x6c\x75\145" => 1, "\162\141\x77" => true], "\102\x4c\117\107\x5f\111\x44\137\103\x55\x52\x52\105\116\x54\x5f\x53\111\x54\x45" => ["\x76\x61\154\x75\145" => 1, "\162\x61\167" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto ce44a; addea: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto B9058; a1ad2: $this->siteEntityManager = $siteEntityManager; goto Fb0ac; Fb0ac: $this->certificateEntityManager = $certificateEntityManager; goto e05fe; ce44a: $this->configManager = $configManager; goto a1ad2; e05fe: $this->databaseEntityManager = $databaseEntityManager; goto fedc4; c383c: parent::__construct($translator, $logger); goto Deb8f; fedc4: $this->databaseUserEntityManager = $databaseUserEntityManager; goto f0f81; f0f81: $this->databaseServerEntityManager = $databaseServerEntityManager; goto addea; B9058: $this->domainNameParser = $domainNameParser; goto d7959; d7959: $this->validator = $validator; goto c383c; Deb8f: } public function index(Request $request) : Response { goto Fbb4a; b1408: $response = $this->render("\106\162\157\156\x74\x65\x6e\144\57\123\151\164\145\57\x4e\145\x77\x2f\x69\156\x64\145\170\56\x68\x74\155\x6c\56\164\x77\x69\147", ["\165\x73\145\162" => $user]); goto A6eba; F7f26: if (true === $hasPermissions) { goto d69a4; } goto fcccd; Fbb4a: $hasPermissions = $this->hasPermissions(); goto F7f26; be22c: d69a4: goto eb043; fcccd: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\x69\164\145\x73")); goto ac6bd; eb043: $user = $this->getUser(); goto b1408; Ede42: return $response; goto c2c5a; A6eba: B9208: goto Ede42; ac6bd: goto B9208; goto be22c; c2c5a: } public function newPythonSite(Request $request) : Response { goto D6aaa; da7e8: $response = $this->redirect($this->generateUrl("\143\x6c\160\137\163\x69\164\x65\x73")); goto E5545; a8b29: if (!(true === $form->isSubmitted())) { goto a8048; } goto dd397; Cbc92: $response = $this->render("\106\162\157\x6e\x74\x65\156\144\x2f\123\x69\x74\x65\x2f\116\145\x77\57\160\171\x74\x68\157\156\56\150\164\155\x6c\x2e\164\x77\151\x67", ["\165\x73\x65\162" => $user, "\146\x6f\162\155" => $form->createView(), "\x66\x6f\x72\x6d\x45\x72\162\x6f\x72\163" => $this->formErrors]); goto E68aa; E9a67: c0a20: goto Dca44; E8b0a: if (!(true === $request->isMethod("\120\117\x53\124"))) { goto Ed0c0; } goto D71a5; F5248: return $response; goto F807c; D6aaa: $hasPermissions = $this->hasPermissions(); goto d3dcf; dd397: $response = $this->handleCreatePythonSiteForm($request, $form); goto fa778; d3dcf: if (true === $hasPermissions) { goto c0a20; } goto da7e8; D71a5: $form->handleRequest($request); goto a8b29; fa778: if (!(false === is_null($response))) { goto a5d40; } goto F5248; E9731: Ed0c0: goto Cbc92; F807c: a5d40: goto Fbc3c; Aefe4: $form = $this->createPythonSiteForm($pythonSettings); goto E8b0a; fca91: return $response; goto F30f3; E68aa: fa5f3: goto fca91; Dca44: $user = $this->getUser(); goto Fe126; E5545: goto fa5f3; goto E9a67; Fbc3c: a8048: goto E9731; Fe126: $pythonSettings = new PythonSettingsEntity(); goto Aefe4; F30f3: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto d4df3; d4df3: $form = $this->createForm("\x41\x70\160\x5c\106\157\x72\155\134\x53\x69\x74\145\116\x65\x77\120\x79\164\x68\x6f\156\124\171\160\x65", $pythonSettings, ["\141\143\164\x69\157\x6e" => $this->generateUrl("\x63\x6c\160\137\163\x69\164\x65\137\x70\x79\164\x68\157\x6e\137\x6e\145\x77"), "\x6d\x65\x74\x68\157\x64" => "\x50\x4f\123\x54", "\x61\x74\164\x72" => ["\151\144" => "\156\145\167\x2d\x70\x79\x74\x68\x6f\x6e\55\x73\151\164\145\55\146\x6f\x72\155"]]); goto Efe3c; Efe3c: $form->add("\x73\165\142\155\151\x74", SubmitType::class, ["\141\x74\x74\x72" => ["\x63\154\x61\x73\x73" => "\142\164\x6e\x20\142\164\156\x2d\x6c\147\40\142\164\156\55\142\154\x75\x65"], "\154\x61\x62\145\154" => "\x43\x72\145\x61\x74\x65"]); goto ddb39; ddb39: return $form; goto f209c; f209c: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto c381a; F6a12: fc1c7: goto B439f; f91f8: try { goto c41f4; e05a1: $session->getFlashBag()->set("\x73\x75\143\x63\145\163\x73", $this->translator->trans("\x53\x69\x74\x65\x20\150\x61\163\x20\142\145\x65\156\x20\143\162\145\x61\x74\x65\x64\56")); goto D8369; c41f4: $session = $request->getSession(); goto Aad2e; Bc323: $port = $form->get("\x70\x6f\162\164")->getData(); goto D0419; Bbcf7: A579e: goto cb2e3; c63b4: $pythonVersion = $form->get("\160\171\x74\150\157\156\126\145\x72\x73\x69\x6f\x6e")->getData(); goto Bc323; F3bd2: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto D60f8; Ce8b2: goto a8e7e; goto Bbcf7; Ab002: a8e7e: goto D00ab; Fb408: $siteUserPassword = $form->get("\163\x69\164\145\x55\x73\145\162\x50\141\x73\163\167\x6f\x72\x64")->getData(); goto ccb83; D60f8: if (false === is_null($vhostTemplateEntity)) { goto A579e; } goto f7bba; De221: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto e05a1; cb2e3: $user = $this->getUser(); goto E1bdc; cf190: return $response; goto Ab002; f7bba: throw new \Exception(sprintf("\126\150\x6f\x73\x74\40\x74\x65\155\160\x6c\141\x74\x65\40\x22\45\x73\x22\40\156\157\x74\x20\x66\157\165\x6e\144\56", $vhostTemplateName)); goto Ce8b2; E1bdc: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto eb19a; Aad2e: $domainName = $form->get("\x64\x6f\x6d\x61\x69\x6e\116\x61\x6d\145")->getData(); goto c63b4; D8369: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\163\151\x74\x65\x73")); goto cf190; D0419: $siteUser = $form->get("\163\151\164\145\125\163\145\x72")->getData(); goto Fb408; eb19a: $eventData = ["\163\x69\x74\145" => $domainName, "\163\151\164\145\x55\x73\145\x72" => $siteUser, "\160\171\x74\150\157\156\126\x65\x72\163\x69\157\156" => $pythonVersion, "\160\157\162\164" => $port]; goto De221; ccb83: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto F3bd2; D00ab: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\156\147\145\x72", $this->translator->trans("\x41\x6e\x20\x65\162\162\157\x72\x20\x68\x61\163\x20\157\x63\143\x75\162\x72\145\144\54\40\x65\162\x72\157\162\40\x6d\145\x73\x73\x61\x67\x65\72\40\45\x65\x72\162\x6f\162\x4d\x65\163\x73\x61\x67\145\x25", ["\x25\145\162\x72\157\162\x4d\145\x73\163\x61\147\x65\x25" => $e->getMessage()])); } goto F6a12; c381a: if (true === $form->isValid()) { goto Dc65d; } goto Eb9b8; Eb9b8: $this->formErrors = $this->getErrorMessages($form); goto b11f3; b11f3: goto fc1c7; goto f9084; f9084: Dc65d: goto f91f8; B439f: } public function newReverseProxy(Request $request) : Response { goto F1889; d8c51: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\x73\151\164\x65\x73")); goto ea0bf; a9b81: B4a53: goto aeea5; fe897: Fd03b: goto a9b81; f7ba8: return $response; goto D7812; daf2e: $user = $this->getUser(); goto f89fa; c8de1: $form->handleRequest($request); goto Dd172; f89fa: $form = $this->createReverseProxyForm(); goto Ddc35; d0f05: if (!(false === is_null($response))) { goto aea00; } goto Bf8ac; Ed43d: eb65d: goto daf2e; F1889: $hasPermissions = $this->hasPermissions(); goto Fafc4; ea0bf: goto bedb4; goto Ed43d; Fafc4: if (true === $hasPermissions) { goto eb65d; } goto d8c51; F41a6: aea00: goto fe897; D962b: bedb4: goto f7ba8; aeea5: $response = $this->render("\106\x72\x6f\x6e\x74\145\x6e\144\57\x53\151\x74\x65\57\x4e\x65\167\x2f\162\x65\x76\145\x72\x73\145\x2d\160\162\x6f\170\171\x2e\150\164\x6d\x6c\56\164\x77\x69\147", ["\x75\x73\x65\x72" => $user, "\x66\157\162\155" => $form->createView(), "\146\x6f\162\155\x45\162\x72\x6f\162\163" => $this->formErrors]); goto D962b; Bf8ac: return $response; goto F41a6; C7b89: $response = $this->handleReverseProxyForm($request, $form); goto d0f05; Ddc35: if (!(true === $request->isMethod("\x50\117\x53\x54"))) { goto B4a53; } goto c8de1; Dd172: if (!(true === $form->isSubmitted())) { goto Fd03b; } goto C7b89; D7812: } private function createReverseProxyForm() : Form { goto c5c76; A87fd: return $form; goto aedac; c5c76: $form = $this->createForm("\101\160\x70\x5c\x46\157\162\x6d\134\x53\151\x74\145\116\145\x77\x52\145\x76\145\x72\163\x65\x50\162\x6f\170\x79\x54\171\160\x65", [], ["\x61\x63\x74\151\157\x6e" => $this->generateUrl("\x63\154\160\x5f\x73\151\x74\x65\x5f\162\145\166\x65\x72\163\145\x5f\x70\x72\x6f\170\x79\137\156\x65\167"), "\155\x65\164\150\157\x64" => "\120\x4f\123\124", "\141\164\x74\162" => ["\151\x64" => "\156\x65\x77\x2d\x72\145\166\145\x72\163\x65\55\160\162\157\x78\x79\55\x66\x6f\x72\x6d"]]); goto B1a45; B1a45: $form->add("\163\165\x62\x6d\151\164", SubmitType::class, ["\x61\164\164\162" => ["\143\x6c\x61\x73\x73" => "\x62\164\156\40\142\x74\x6e\x2d\154\147\40\x62\164\156\55\142\x6c\165\x65"], "\x6c\x61\x62\x65\x6c" => "\x43\162\145\141\164\145"]); goto A87fd; aedac: } private function handleReverseProxyForm(Request $request, Form $form) { goto B6cbf; f57ff: B3deb: goto Df974; B6cbf: if (true === $form->isValid()) { goto B3deb; } goto bc734; Df974: try { goto af0e0; F9c39: cb796: goto e56a1; e56a1: $user = $this->getUser(); goto Edb2b; e1f0a: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\163\x69\164\x65\163")); goto f0a30; f5e82: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto c79cc; cc35b: $domainName = $form->get("\x64\157\x6d\x61\x69\156\116\x61\155\145")->getData(); goto F4a12; Cd712: $eventData = ["\x73\151\164\145" => $domainName, "\x73\151\x74\x65\x55\x73\145\x72" => $siteUser, "\162\145\166\x65\162\163\x65\x50\x72\157\x78\x79\x55\x72\x6c" => $reverseProxyUrl]; goto f5e82; D9017: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto Ab195; c79cc: $session->getFlashBag()->set("\x73\165\143\x63\x65\x73\163", $this->translator->trans("\122\145\x76\x65\x72\x73\145\x20\120\x72\x6f\170\171\40\x68\x61\x73\40\142\x65\145\x6e\40\x63\x72\x65\x61\x74\x65\x64\x2e")); goto e1f0a; F4a12: $siteUser = $form->get("\163\151\164\145\125\163\x65\162")->getData(); goto eef73; Edb2b: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto Cd712; Ab195: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto efd2b; c2602: $reverseProxyUrl = $form->get("\162\145\x76\x65\x72\x73\145\x50\x72\x6f\170\171\125\x72\x6c")->getData(); goto D9017; eef73: $siteUserPassword = $form->get("\163\x69\164\x65\x55\163\145\x72\120\x61\x73\x73\167\157\x72\x64")->getData(); goto c2602; af0e0: $session = $request->getSession(); goto cc35b; Eb449: throw new \Exception(sprintf("\126\150\157\163\x74\40\164\145\155\160\154\x61\164\x65\x20\42\x25\163\42\x20\156\x6f\x74\40\146\157\165\156\144\56", $vhostTemplateName)); goto b1eac; efd2b: if (false === is_null($vhostTemplateEntity)) { goto cb796; } goto Eb449; b1eac: goto e9991; goto F9c39; f0a30: return $response; goto B8140; B8140: e9991: goto bd359; bd359: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\145\162", $this->translator->trans("\101\x6e\40\145\x72\x72\157\162\40\150\141\163\40\x6f\x63\x63\165\x72\162\145\x64\x2c\x20\145\x72\x72\157\x72\x20\155\145\163\163\x61\x67\x65\x3a\x20\45\145\x72\x72\x6f\x72\x4d\x65\163\x73\x61\147\145\x25", ["\x25\145\162\x72\157\x72\x4d\145\x73\x73\141\x67\145\x25" => $e->getMessage()])); } goto bfa66; bc734: $this->formErrors = $this->getErrorMessages($form); goto De50d; bfa66: c7b57: goto C94f6; De50d: goto c7b57; goto f57ff; C94f6: } public function newNodejsSite(Request $request) : Response { goto D0094; b417d: if (!(false === is_null($response))) { goto D8228; } goto D784a; D0094: $hasPermissions = $this->hasPermissions(); goto b9076; C297a: D8228: goto f58f1; F7819: df9e6: goto D9a95; acda9: $response = $this->handleCreateNodejsSiteForm($request, $form); goto b417d; Ea6af: $form = $this->createNodejsSiteForm($nodejsSettings); goto d5ba2; bfd5d: goto B95c8; goto A93db; a3b9b: $nodejsSettings = new NodejsSettingsEntity(); goto Ea6af; F59d7: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\x69\164\x65\x73")); goto bfd5d; d5ba2: if (!(true === $request->isMethod("\120\x4f\x53\x54"))) { goto df9e6; } goto a1c3f; f58f1: B9aab: goto F7819; D9a95: $response = $this->render("\106\162\157\x6e\164\x65\156\x64\57\123\x69\164\x65\57\116\x65\x77\x2f\156\157\x64\x65\152\163\56\150\x74\155\x6c\56\164\x77\151\x67", ["\x75\163\145\x72" => $user, "\146\157\x72\x6d" => $form->createView(), "\146\x6f\162\x6d\x45\x72\162\x6f\x72\163" => $this->formErrors]); goto d25db; D784a: return $response; goto C297a; a1c3f: $form->handleRequest($request); goto F319c; F319c: if (!(true === $form->isSubmitted())) { goto B9aab; } goto acda9; A93db: c1882: goto Fc9a7; Fc9a7: $user = $this->getUser(); goto a3b9b; b9076: if (true === $hasPermissions) { goto c1882; } goto F59d7; b6e64: return $response; goto B5257; d25db: B95c8: goto b6e64; B5257: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto a8dd0; a7453: return $form; goto Fbd3e; a8dd0: $form = $this->createForm("\101\160\160\134\x46\x6f\162\155\x5c\123\151\164\x65\116\145\x77\116\x6f\144\x65\x6a\x73\124\x79\x70\145", $nodejsSettings, ["\141\143\164\151\x6f\156" => $this->generateUrl("\x63\x6c\160\137\x73\151\164\x65\137\156\157\x64\x65\152\163\x5f\x6e\x65\167"), "\155\145\x74\150\157\144" => "\x50\117\123\124", "\x61\164\164\x72" => ["\151\144" => "\156\x65\167\55\x6e\x6f\144\145\152\x73\55\x73\x69\x74\145\x2d\x66\157\162\x6d"]]); goto D0048; D0048: $form->add("\163\165\x62\155\x69\x74", SubmitType::class, ["\x61\x74\164\x72" => ["\x63\x6c\141\x73\163" => "\x62\x74\156\40\142\164\156\x2d\154\x67\40\x62\164\156\x2d\142\154\x75\145"], "\x6c\141\142\145\x6c" => "\x43\162\145\141\x74\145"]); goto a7453; Fbd3e: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto fd708; cb533: F041a: goto D56cb; D56cb: try { goto efc4f; a1e06: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto E7878; C47ee: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto D06b1; C55e7: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto D64ea; b404c: $siteUserPassword = $form->get("\x73\x69\164\145\125\x73\x65\162\120\x61\163\x73\x77\157\162\x64")->getData(); goto C1523; fdf16: $siteUser = $form->get("\163\151\164\x65\x55\163\145\162")->getData(); goto b404c; aa627: $nodejsVersion = $form->get("\x6e\x6f\x64\145\152\163\x56\x65\162\163\x69\157\x6e")->getData(); goto Ce266; e75d0: $user = $this->getUser(); goto C47ee; Dc6a4: throw new \Exception(sprintf("\126\150\x6f\x73\164\40\x74\x65\x6d\160\154\141\164\x65\40\x22\45\x73\42\40\156\x6f\164\x20\x66\157\x75\156\x64\56", $vhostTemplateName)); goto Eb03e; D06b1: $eventData = ["\x73\x69\164\x65" => $domainName, "\x73\x69\164\x65\125\x73\145\162" => $siteUser, "\156\157\144\145\152\163\126\145\x72\x73\x69\x6f\x6e" => $nodejsVersion, "\160\x6f\x72\164" => $port]; goto a1e06; Eb03e: goto A29ab; goto a9dee; C1523: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto C55e7; d8c3c: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\x73\151\x74\145\x73")); goto F3517; C1143: A29ab: goto Bc0b7; fc2e1: $domainName = $form->get("\x64\157\155\141\x69\156\116\141\x6d\145")->getData(); goto aa627; E7878: $session->getFlashBag()->set("\163\165\143\x63\x65\163\x73", $this->translator->trans("\x53\151\x74\x65\40\150\141\x73\40\142\x65\x65\x6e\40\x63\x72\x65\x61\x74\145\144\x2e")); goto d8c3c; efc4f: $session = $request->getSession(); goto fc2e1; D64ea: if (false === is_null($vhostTemplateEntity)) { goto d0ae7; } goto Dc6a4; F3517: return $response; goto C1143; a9dee: d0ae7: goto e75d0; Ce266: $port = $form->get("\160\157\x72\164")->getData(); goto fdf16; Bc0b7: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\147\x65\x72", $this->translator->trans("\101\x6e\x20\x65\x72\162\157\162\40\x68\x61\163\x20\x6f\x63\x63\165\x72\162\145\144\x2c\x20\x65\x72\x72\157\x72\x20\155\145\x73\x73\141\147\145\x3a\x20\45\145\x72\x72\x6f\162\x4d\x65\163\x73\x61\147\145\x25", ["\45\145\162\162\157\162\x4d\x65\x73\163\141\x67\145\45" => $e->getMessage()])); } goto fb77e; E3fb9: goto baff1; goto cb533; fd708: if (true === $form->isValid()) { goto F041a; } goto Dcd91; fb77e: baff1: goto a5ba9; Dcd91: $this->formErrors = $this->getErrorMessages($form); goto E3fb9; a5ba9: } public function newStaticSite(Request $request) : Response { goto B961a; d68cf: return $response; goto e5fbb; f3205: $response = $this->handleCreateStaticSiteForm($request, $form); goto F5cf4; A9fe7: Ec65f: goto c5da4; f34cd: $form->handleRequest($request); goto ccdd0; Ab6f5: goto Ec65f; goto ca085; E6ba0: $user = $this->getUser(); goto Cfdae; B8ca2: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\x73\x69\x74\145\x73")); goto Ab6f5; c5da4: return $response; goto C9b32; Cfdae: $form = $this->createStaticSiteForm(); goto b6275; ec614: Be587: goto C68c2; C68c2: $response = $this->render("\x46\x72\157\156\x74\145\156\144\57\x53\x69\164\x65\x2f\116\x65\167\57\163\x74\x61\x74\x69\143\x2e\150\x74\x6d\x6c\56\164\x77\x69\147", ["\x75\x73\145\162" => $user, "\146\157\162\x6d" => $form->createView(), "\x66\157\162\x6d\105\x72\x72\x6f\162\163" => $this->formErrors]); goto A9fe7; d9cca: b18f1: goto ec614; e5fbb: edbc8: goto d9cca; b6275: if (!(true === $request->isMethod("\x50\x4f\123\x54"))) { goto Be587; } goto f34cd; D4f8e: if (true === $hasPermissions) { goto b1a56; } goto B8ca2; B961a: $hasPermissions = $this->hasPermissions(); goto D4f8e; ca085: b1a56: goto E6ba0; ccdd0: if (!(true === $form->isSubmitted())) { goto b18f1; } goto f3205; F5cf4: if (!(false === is_null($response))) { goto edbc8; } goto d68cf; C9b32: } private function createStaticSiteForm() : Form { goto D3816; d35a8: $form->add("\163\x75\x62\x6d\151\164", SubmitType::class, ["\x61\x74\x74\x72" => ["\143\x6c\141\x73\163" => "\142\x74\156\40\x62\x74\x6e\55\154\147\x20\x62\x74\x6e\x2d\x62\x6c\165\x65"], "\x6c\x61\142\145\154" => "\x43\162\x65\x61\164\x65"]); goto D6273; D3816: $form = $this->createForm("\x41\160\x70\x5c\106\157\x72\x6d\134\123\151\164\145\116\x65\167\123\164\x61\164\151\143\124\x79\x70\x65", [], ["\141\143\164\x69\x6f\156" => $this->generateUrl("\143\154\x70\x5f\163\151\164\x65\x5f\163\x74\141\x74\x69\x63\x5f\156\145\167"), "\155\145\x74\x68\157\144" => "\x50\x4f\x53\124", "\x61\x74\x74\x72" => []]); goto d35a8; D6273: return $form; goto cc82e; cc82e: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto eb105; f39e6: $this->formErrors = $this->getErrorMessages($form); goto f675d; eb105: if (true === $form->isValid()) { goto e770e; } goto f39e6; d8699: try { goto c58e2; f84b7: throw new \Exception(sprintf("\126\150\157\163\164\x20\164\x65\x6d\x70\x6c\x61\x74\145\x20\42\45\163\x22\40\x6e\x6f\164\x20\x66\x6f\165\156\x64\56", $vhostTemplateName)); goto e6170; b18dd: aea7f: goto Ef2ac; B3ce1: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto ffcec; bf5e7: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto f6ecb; C7f25: $domainName = $form->get("\x64\x6f\155\x61\151\156\x4e\x61\155\x65")->getData(); goto A8435; a4e7f: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto Eed88; e6170: goto aea7f; goto f161b; E64ca: $siteUserPassword = $form->get("\x73\x69\164\x65\x55\x73\145\162\x50\x61\163\163\x77\157\162\144")->getData(); goto c26bb; c26bb: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto B3ce1; f161b: f45fb: goto f627a; c58e2: $session = $request->getSession(); goto C7f25; f6727: return $response; goto b18dd; A8435: $siteUser = $form->get("\163\x69\164\x65\125\x73\145\162")->getData(); goto E64ca; f6ecb: $eventData = ["\x73\x69\164\145" => $domainName, "\x73\x69\x74\x65\125\x73\145\162" => $siteUser]; goto a4e7f; ffcec: if (false === is_null($vhostTemplateEntity)) { goto f45fb; } goto f84b7; f627a: $user = $this->getUser(); goto bf5e7; f066c: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\163\x69\164\145\x73")); goto f6727; Eed88: $session->getFlashBag()->set("\163\165\143\143\x65\163\163", $this->translator->trans("\x53\x69\164\x65\x20\150\141\163\40\x62\x65\145\x6e\x20\x63\x72\145\x61\164\x65\144\x2e")); goto f066c; Ef2ac: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\x67\x65\162", $this->translator->trans("\101\x6e\40\145\x72\x72\157\x72\40\x68\x61\163\x20\157\x63\143\x75\x72\162\145\x64\54\x20\145\x72\x72\x6f\x72\40\155\x65\163\x73\x61\147\x65\72\40\x25\145\162\x72\x6f\x72\115\145\x73\163\141\147\145\45", ["\45\x65\x72\162\157\162\115\145\163\163\141\147\x65\x25" => $e->getMessage()])); } goto Be901; f675d: goto f70fc; goto B7701; B7701: e770e: goto d8699; Be901: f70fc: goto c5259; c5259: } public function newPhpSite(Request $request) : Response { goto b779d; A1fad: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\163\151\x74\x65\163")); goto C4f9c; b9d86: if (!(false === is_null($response))) { goto ae388; } goto Fe590; C4f9c: goto af4bd; goto a6ba1; Ea36d: return $response; goto a0739; C8bf1: $response = $this->handleCreatePhpSiteForm($request, $form); goto b9d86; Fa583: $user = $this->getUser(); goto Eed99; D4b10: $response = $this->render("\106\162\x6f\156\x74\145\x6e\144\x2f\x53\151\x74\145\57\x4e\145\167\57\x70\x68\x70\56\150\x74\155\154\56\164\x77\x69\147", ["\x75\x73\x65\162" => $user, "\146\157\162\155" => $form->createView(), "\x66\x6f\162\155\105\x72\x72\x6f\x72\163" => $this->formErrors]); goto c4059; E1192: if (!(true === $form->isSubmitted())) { goto Fc5d6; } goto C8bf1; c4059: af4bd: goto Ea36d; B2374: C85df: goto D4b10; D5f18: ae388: goto E8323; E2e17: if (!(true === $request->isMethod("\x50\117\x53\x54"))) { goto C85df; } goto e79df; a6ba1: d17fa: goto Fa583; Fe590: return $response; goto D5f18; E8323: Fc5d6: goto B2374; e79df: $form->handleRequest($request); goto E1192; b779d: $hasPermissions = $this->hasPermissions(); goto Fe333; Eed99: $form = $this->createPhpSiteForm(); goto E2e17; Fe333: if (true === $hasPermissions) { goto d17fa; } goto A1fad; a0739: } private function createPhpSiteForm() : Form { goto B770e; e9173: return $form; goto B63b7; e1c6b: $form->add("\163\x75\142\155\x69\164", SubmitType::class, ["\141\x74\x74\x72" => ["\x63\x6c\x61\x73\163" => "\x62\x74\156\x20\x62\x74\x6e\x2d\x6c\147\40\x62\164\156\x2d\142\x6c\x75\145"], "\154\141\142\145\154" => "\x43\162\x65\141\164\145"]); goto e9173; B770e: $form = $this->createForm("\x41\160\160\x5c\x46\x6f\x72\x6d\x5c\x53\151\x74\x65\116\145\x77\120\150\160\124\x79\x70\x65", [], ["\141\x63\164\151\x6f\x6e" => $this->generateUrl("\143\154\160\x5f\163\151\x74\x65\x5f\160\x68\160\x5f\156\145\167"), "\x6d\145\164\150\x6f\x64" => "\120\117\x53\124", "\x61\164\x74\x72" => []]); goto e1c6b; B63b7: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto a4371; e2e2f: try { goto A8351; A8351: $session = $request->getSession(); goto Ac271; b943a: C6df4: goto B12af; B06f3: $siteUserPassword = $form->get("\x73\151\164\145\x55\163\145\162\120\x61\x73\x73\167\x6f\x72\144")->getData(); goto B6af7; Da8e6: $rootDirectory = $domainName; goto e17fb; f7132: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\163\x69\164\145\163")); goto b2f69; E85dc: $domainName = $form->get("\144\157\x6d\x61\151\156\116\x61\x6d\x65")->getData(); goto F4b95; df346: if (false === is_null($vhostTemplateEntity)) { goto C6df4; } goto Fffee; ecfce: goto Cf0a7; goto b943a; A1782: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto A32e6; F4b95: $phpVersion = $form->get("\160\150\x70\x56\145\162\163\x69\x6f\x6e")->getData(); goto b8b5d; e17fb: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto B4298; } goto D193a; b2f69: return $response; goto C09b9; D193a: $rootDirectory = sprintf("\45\163\57\x25\163", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\x2f")); goto Dadea; b63fc: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto b69b1; B12af: $user = $this->getUser(); goto Da8e6; Dadea: B4298: goto Dfdc2; B6af7: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto df346; C09b9: Cf0a7: goto Ce40e; aee11: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto A0004; } goto Dcef4; Dcef4: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto Cd2af; Fffee: throw new \Exception(sprintf("\x56\x68\157\x73\164\x20\164\145\155\x70\x6c\x61\x74\x65\x20\42\45\x73\x22\40\x6e\157\x74\40\x66\157\165\156\144\x2e", $vhostTemplateName)); goto ecfce; Dfdc2: $varnishCacheSettings = []; goto aee11; Cd2af: A0004: goto A1782; A32e6: $eventData = ["\x73\151\164\145" => $domainName, "\166\x68\x6f\x73\164\x54\145\155\x70\154\x61\x74\x65\x4e\x61\x6d\145" => $vhostTemplateName, "\x70\150\160\126\x65\162\163\151\x6f\156" => $phpVersion, "\x73\151\x74\145\125\x73\145\x72" => $siteUser]; goto b63fc; b69b1: $session->getFlashBag()->set("\163\x75\x63\x63\x65\163\x73", $this->translator->trans("\x53\151\x74\x65\x20\150\141\x73\40\x62\x65\x65\x6e\x20\143\x72\145\141\164\145\x64\56")); goto f7132; Ac271: $vhostTemplateName = $form->get("\141\x70\160\x6c\151\143\x61\164\x69\x6f\156")->getData(); goto E85dc; b8b5d: $siteUser = $form->get("\163\x69\164\x65\x55\163\145\162")->getData(); goto B06f3; Ce40e: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\147\145\x72", $this->translator->trans("\101\x6e\x20\145\162\x72\x6f\x72\40\x68\x61\163\40\x6f\x63\143\x75\162\x72\145\x64\54\40\145\x72\162\x6f\162\40\155\145\x73\163\x61\147\x65\x3a\40\x25\145\x72\162\x6f\162\115\145\x73\x73\141\147\x65\45", ["\45\x65\x72\162\157\162\115\x65\x73\163\x61\x67\145\x25" => $e->getMessage()])); } goto A3e36; ecbb7: $this->formErrors = $this->getErrorMessages($form); goto Aaf5f; Aaf5f: goto d420f; goto E9888; a4371: if (true === $form->isValid()) { goto b62b6; } goto ecbb7; E9888: b62b6: goto e2e2f; A3e36: d420f: goto ac1d9; ac1d9: } public function newWordPressSite(Request $request) : Response { goto E0c0f; C171f: return $response; goto Cae2e; d99d2: $form->handleRequest($request); goto f2122; f2122: if (!(true === $form->isSubmitted())) { goto e611a; } goto Fc1bf; fb103: $user = $this->getUser(); goto Cbcaf; E2756: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\x73\x69\x74\145\x73")); goto f4f06; e5cc5: return $response; goto e1603; f4f06: goto E1a52; goto Ffc0c; b3008: ffa05: goto B7442; F61b4: e611a: goto b3008; Cbcaf: $form = $this->createWordPressSiteForm(); goto F7e5c; d472d: if (true === $hasPermissions) { goto B6451; } goto E2756; F7e5c: if (!(true === $request->isMethod("\120\x4f\123\124"))) { goto ffa05; } goto d99d2; E0c0f: $hasPermissions = $this->hasPermissions(); goto d472d; Cae2e: a27dd: goto F61b4; c8f7e: if (!(false === is_null($response))) { goto a27dd; } goto C171f; Fc1bf: $response = $this->handleCreateWordPressSiteForm($request, $form); goto c8f7e; C65d3: E1a52: goto e5cc5; Ffc0c: B6451: goto fb103; B7442: $response = $this->render("\106\162\x6f\156\164\x65\x6e\x64\x2f\x53\x69\164\x65\57\x4e\x65\167\x2f\167\x6f\x72\144\160\x72\x65\x73\163\x2e\x68\164\x6d\154\56\164\167\x69\x67", ["\165\163\x65\x72" => $user, "\x66\157\162\x6d" => $form->createView(), "\146\x6f\x72\x6d\x45\162\162\x6f\x72\163" => $this->formErrors]); goto C65d3; e1603: } private function createWordPressSiteForm() : Form { goto fe2a7; f8b17: $form->add("\163\x75\x62\x6d\151\x74", SubmitType::class, ["\141\164\x74\162" => ["\x63\x6c\141\x73\x73" => "\142\x74\156\40\142\164\156\x2d\154\147\x20\x62\164\x6e\55\x62\x6c\165\145"], "\154\141\142\x65\154" => "\103\162\x65\141\164\x65"]); goto Efd3a; Efd3a: return $form; goto Cdd5a; fe2a7: $form = $this->createForm("\x41\x70\x70\x5c\106\157\162\x6d\x5c\123\151\x74\x65\x4e\145\167\127\x6f\162\x64\120\162\145\x73\163\124\171\x70\145", [], ["\x61\143\164\151\x6f\156" => $this->generateUrl("\143\x6c\x70\137\x73\151\164\x65\137\x77\x6f\x72\x64\x70\162\145\163\x73\x5f\x6e\x65\x77"), "\155\x65\x74\x68\157\144" => "\x50\117\x53\x54", "\x61\x74\164\162" => ["\151\x64" => "\156\x65\x77\55\x77\157\162\144\160\x72\145\163\x73\55\163\x69\x74\145\55\146\x6f\162\155"]]); goto f8b17; Cdd5a: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto b9f70; Fa37b: goto A7b20; goto Fc44c; b9f70: if (true === $form->isValid()) { goto b120a; } goto B4240; Ff987: A7b20: goto Bfb83; A3187: try { goto E103a; f1db2: $siteEntity->addDatabase($databaseEntity); goto fc6ba; aeead: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto e0301; Bb500: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto b517e; d14de: $databaseManager->createDatabase($databaseEntity); goto Bd07a; E957f: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto D32ce; } goto f1790; C4668: $databaseEntity->setName($databaseName); goto fbf47; b5c55: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto D2ad0; ae6d5: $session->set("\x73\151\x74\145\x43\162\x65\x64\145\156\164\x69\x61\x6c\x73", $siteCredentials); goto f3165; c1d72: $databaseName = $this->getUniqueDatabaseName($generatedName); goto dc33b; c64f1: $databaseEntity->addUser($databaseUserEntity); goto f1db2; C51ea: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto C4668; b5dd0: $title = $form->get("\x73\x69\x74\x65\124\151\x74\x6c\145")->getData(); goto A56b8; c7e5a: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto b5c55; e4470: if (!(false === is_null($siteEntity))) { goto Fa5a1; } goto c1d72; Fbb1c: $adminEmail = $form->get("\x61\144\x6d\151\x6e\x45\x6d\141\x69\154")->getData(); goto dc0eb; e0301: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\x73\x69\164\x65\137\167\157\x72\144\x70\162\145\163\163\x5f\x69\156\x73\x74\141\154\154\x65\144")); goto f7728; f3165: $eventData = ["\x73\x69\164\x65" => $domainName, "\x73\x69\x74\145\125\163\x65\x72" => $siteUser]; goto aeead; ad9ac: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto A6851; f7728: return $response; goto ba422; D2ad0: $databaseUserEntity->setDatabase($databaseEntity); goto c64f1; A6851: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto de7e5; f6be0: $varnishCacheSettings = []; goto E957f; B346d: $siteUserPassword = $form->get("\x73\x69\164\145\125\163\x65\162\x50\141\163\x73\167\x6f\x72\144")->getData(); goto c27aa; A56b8: $adminUserName = $form->get("\141\144\155\x69\x6e\x55\x73\145\x72\x4e\141\x6d\145")->getData(); goto F3bd0; F2ad4: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto d4f76; f666a: $url = sprintf("\x68\164\x74\160\x73\x3a\57\57\45\163", $siteEntity->getDomainName()); goto b5dd0; E103a: $user = $this->getUser(); goto ee980; a4903: $siteCredentials = [$this->translator->trans("\123\151\x74\145") => [$this->translator->trans("\111\120\x20\x41\144\144\162\145\x73\163") => $instance->getIpv4PublicIp(), $this->translator->trans("\x44\x6f\155\x61\x69\x6e\40\116\x61\155\x65") => sprintf("\150\164\x74\x70\x73\x3a\57\x2f\45\x73", $domainName), $this->translator->trans("\x53\x69\x74\x65\40\x55\x73\x65\x72") => $siteUser, $this->translator->trans("\x50\x61\x73\x73\x77\157\x72\x64") => $siteUserPassword]]; goto e4470; A8d47: Fa5a1: goto ae6d5; cae0a: $generatedName = $this->generateNameFromDomainName($domainName); goto cad89; A4329: $siteCredentials["\127\157\x72\144\x50\162\145\163\163"] = [$this->translator->trans("\101\144\155\151\156\40\x45\x2d\115\x61\151\x6c") => $adminEmail, $this->translator->trans("\x41\x64\155\151\156\40\125\163\145\162\40\116\x61\x6d\x65") => $adminUserName, $this->translator->trans("\x41\144\x6d\x69\x6e\x20\x50\x61\x73\163\167\x6f\x72\x64") => $adminPassword, $this->translator->trans("\x41\144\x6d\151\x6e\40\x55\162\154") => sprintf("\x68\x74\164\x70\163\72\x2f\57\x25\x73\57\x77\x70\x2d\x61\144\155\151\x6e\x2f", rtrim($domainName, "\x2f"))]; goto A8d47; b517e: $siteCredentials[$this->translator->trans("\x44\141\x74\x61\x62\141\163\x65")] = [$this->translator->trans("\x48\x6f\x73\164") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\x50\x6f\x72\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\x44\x61\x74\141\x62\141\x73\x65\40\116\x61\155\145") => $databaseName, $this->translator->trans("\104\x61\164\x61\x62\x61\163\145\x20\x55\x73\145\162\x20\116\141\155\145") => $databaseUserName, $this->translator->trans("\x44\141\164\141\x62\x61\x73\x65\40\x55\x73\145\x72\x20\x50\x61\163\x73\167\x6f\162\x64") => $databaseUserPassword]; goto A4329; C6a08: $domainName = $form->get("\144\157\155\x61\x69\156\116\x61\x6d\x65")->getData(); goto cae0a; Bd07a: $databaseManager->createUser($databaseUserEntity); goto Aa506; ee20d: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto f666a; fc6ba: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto d14de; e8b22: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto f6be0; dc33b: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto ee20d; ee980: $session = $request->getSession(); goto C6a08; A5744: D32ce: goto ad9ac; F3bd0: $adminPassword = $form->get("\x61\144\155\151\156\120\141\163\163\x77\157\162\144")->getData(); goto Fbb1c; dc0eb: $isMultiSite = $form->get("\x6d\x75\x6c\x74\x69\123\151\164\x65")->getData(); goto F2ad4; fbf47: $databaseEntity->setSite($siteEntity); goto E7310; d4f76: $databaseEntity = $this->databaseEntityManager->createEntity(); goto C51ea; cad89: $siteUser = $form->get("\x73\151\164\x65\x55\x73\x65\x72")->getData(); goto B346d; de7e5: $instance = $request->attributes->get("\x69\156\163\164\x61\156\x63\x65"); goto a4903; a717e: $databaseUserEntity->setUserName($databaseUserName); goto c7e5a; E7310: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto a717e; f1790: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto A5744; c27aa: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto e8b22; Aa506: $this->siteEntityManager->updateEntity($siteEntity); goto Bb500; ba422: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\x67\x65\162", $this->translator->trans("\x41\156\x20\145\x72\162\157\162\x20\150\x61\x73\40\157\x63\x63\165\162\x72\x65\x64\54\x20\x65\x72\x72\x6f\x72\40\x6d\x65\x73\163\x61\x67\x65\x3a\40\x25\145\162\x72\157\x72\115\x65\163\163\x61\147\x65\x25", ["\45\x65\162\162\x6f\x72\x4d\145\x73\163\141\147\x65\45" => $e->getMessage()])); } goto Ff987; B4240: $this->formErrors = $this->getErrorMessages($form); goto Fa37b; Fc44c: b120a: goto A3187; Bfb83: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto E4bdb; E2565: B0dc0: goto ed75a; b0a2b: $this->wordPressMultiSiteConfigValues["\x44\x4f\115\101\111\x4e\x5f\x43\x55\x52\122\105\116\124\x5f\x53\x49\124\x45"]["\x76\141\154\165\x65"] = $siteEntity->getDomainName(); goto dce10; Afd6e: if (!(true === $isMultiSite)) { goto fa51c; } goto b0a2b; F5a3c: $wordPressInstaller->resetPermissions(); goto b9adc; dce10: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\141\x6c\x75\x65"], $config["\162\141\167"]); b8863: } goto E2565; e34e9: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto c5d17; c5d17: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\x61\x6c\165\145"], $config["\162\x61\167"]); ad728: } goto Df7b5; E2d5b: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto d28f8; d28f8: $wordPressInstaller = new WordPressInstaller($siteEntity); goto Cf4a2; dcac0: $databaseName = $databaseEntity->getName(); goto B6e66; Df7b5: b5047: goto Afd6e; Cf4a2: $wordPressInstaller->downloadAndExtractLatestVersion(); goto f2512; ed75a: fa51c: goto F5a3c; f2512: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto e34e9; E4bdb: $databaseHost = sprintf("\x25\x73\72\45\163", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto dcac0; B6e66: $databaseUserName = $databaseUserEntity->getUserName(); goto E2d5b; b9adc: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto d603c; C9316: $certificateEntity->setDefaultCertificate(true); goto c9610; bd9f8: $siteConstraints = $this->validator->validate($siteEntity); goto c8895; Bffc6: if (!(false === is_null($subdomain) && "\167\x77\x77" == $subdomain)) { goto B7849; } goto F783e; Cd53c: $subjectAlternativeNames = []; goto e0a79; b0ea6: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto Df9c1; C94c2: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto F2c1b; C83d0: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto e2bfd; Ea83e: $phpSettingsEntity = new PhpSettingsEntity(); goto Af890; D2dc7: $phpSite->setPhpSettings($phpSettingsEntity); goto Bd1ff; dc952: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto C83d0; B0978: $phpSiteCreator->createPrivateKeyAndCertificate(); goto b5115; b8c46: $phpSiteCreator->reloadNginxService(); goto E6ab9; dfd94: $siteEntity->setType(SiteEntity::TYPE_PHP); goto dc969; d228b: $constraintViolationList->addAll($phpSettingsConstraints); goto dc952; F24c2: $subdomain = false === empty($subdomain) ? $subdomain : null; goto B695c; Fcd3a: $phpSiteCreator->reloadPhpFpmService(); goto De9fe; C5690: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto e4d74; Ed4dc: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Cd53c; D6923: e970c: goto Fd449; F644d: $phpSite->setCertificate($certificateEntity); goto D2dc7; A7ae7: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto d1492; e0f56: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto Fa8c3; } goto ff71d; b72a6: Fa8c3: goto b4183; c9117: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\57\x2e\56\57\56\x2e\x2f\x72\145\x73\x6f\165\162\143\145\163\x2f\156\x67\x69\x6e\x78\57\166\x68\157\x73\x74\x5f\164\145\155\160\154\141\164\x65\x2f\x72\x65\x64\x69\162\145\x63\164"); goto C9997; Df9c1: fe045: goto A5466; A0dde: if (!(false === empty($redirectionVhostTemplate))) { goto ea1ed; } goto cff82; c1003: $phpSiteCreator->createUser(); goto Ba356; Bd439: $phpSite->setSubdomain($subdomain); goto Dad8d; F74f9: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto D9514; A5466: $phpSiteCreator->createNginxVhost(); goto b8c46; E1c2f: $siteEntity->setVarnishCache(true); goto E3ace; F029d: $siteEntity->setCertificate($certificateEntity); goto Bcc77; ba1f4: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Ce718; ec99f: $constraintViolationList->addAll($siteConstraints); goto d228b; e9cff: ebbfc: goto Fe4d1; c8895: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto A74c6; F783e: $subjectAlternativeNames[] = $registrableDomain; goto A2810; F3d63: $siteEntity->setRootDirectory($rootDirectory); goto ceb5f; ff71d: if (true === isset($_ENV["\101\x50\x50\137\110\x54\x54\120\x33"]) && "\x74\162\x75\145" === $_ENV["\101\x50\120\137\110\x54\124\x50\x33"]) { goto ebbfc; } goto c9117; Fe4d1: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\x2f\x2e\x2e\x2f\56\x2e\57\162\x65\163\157\165\x72\x63\145\x73\x2f\156\x67\151\x6e\x78\57\x76\x68\x6f\x73\x74\137\x74\x65\x6d\x70\154\x61\164\145\x2f\x72\x65\x64\x69\162\x65\x63\164\55\x68\x74\x74\160\x33"); goto D6923; Bcc77: $phpSite = new PhpSite(); goto b9ccb; bc02f: $constraintViolationList = new ConstraintViolationList(); goto ec99f; A74c6: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto Ae1a4; } goto bc02f; B695c: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto F74f9; C5798: $phpSite->setVarnishCache(true); goto F260f; b94d2: $siteEntity->setUser($siteUser); goto C1c61; Af890: $siteEntity->setPhpSettings($phpSettingsEntity); goto fbaaa; Bd17e: ea1ed: goto b72a6; ec8b6: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto d2552; b5115: $phpSiteCreator->createPhpFpmPool(); goto Fcd3a; b1c3d: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto f852d; ea722: $certificateEntity->setCertificate($selfSignedCertificate); goto F029d; Dad8d: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto F644d; Ce0cf: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto b0ea6; E6ab9: $phpSiteCreator->resetPermissions(); goto F1b1b; f852d: $phpSite->setDomainName($domainName); goto be4ce; c5896: $phpSiteCreator->createIndexPhp(); goto B0978; a9a35: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto Ce0cf; C1c61: $siteEntity->setUserPassword($siteUserPassword); goto F3d63; Bfd3d: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto ca47c; Cb5a5: $rsaKeyGenerator = new RsaKeyGenerator(); goto Ed4dc; e4b7a: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto ec8b6; F2c1b: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto F5e20; e4d74: $csr = $csrGenerator->generate(); goto e499e; E3ace: de55d: goto e0f56; e499e: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto C9316; fbaaa: $phpSettingsEntity->setPhpVersion($phpVersion); goto a88a1; b9ccb: $phpSite->setUser($siteEntity->getUser()); goto b1c3d; B6075: $certificateEntity->setCsr($csr); goto dc256; ae2fb: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto C5690; E27ac: $vhostTemplate->build(); goto C94c2; dc969: $siteEntity->setDomainName($domainName); goto b94d2; D9514: $siteEntity = $this->siteEntityManager->createEntity(); goto dfd94; d603c: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto F3076; cff82: $vhostTemplate = sprintf("\45\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto Bd17e; be4ce: $phpSite->setRegistrableDomain($registrableDomain); goto Bd439; F5e20: $this->siteEntityManager->updateEntity($siteEntity); goto Bbf84; C7428: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto A7ae7; Ce718: $certificateEntity->setSite($siteEntity); goto Cb5a5; d1492: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto E27ac; Bd1ff: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Eb0f3; e0a79: if (!(true === is_null($subdomain))) { goto d3398; } goto d866b; dc256: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto ea722; a88a1: $phpSettingsEntity->setSite($siteEntity); goto bd9f8; De9fe: if (!(true === $varnishCache)) { goto fe045; } goto C5798; e2bfd: Ae1a4: goto ba1f4; ca47c: $vhostTemplate->resetProcessors(); goto C7428; F260f: $defaultVarnishCacheSettings = ["\145\156\x61\142\154\x65\x64" => false, "\x73\x65\162\166\145\162" => self::VARNISH_CACHE_SERVER, "\x63\x61\x63\150\x65\x54\141\147\120\162\145\x66\151\x78" => substr(md5(time()), 0, 4)]; goto a9a35; d2552: $subdomain = $resolvedDomainName->subDomain()->toString(); goto F24c2; A2810: B7849: goto ae2fb; Bbf84: return $siteEntity; goto d1f92; Ba356: $phpSiteCreator->createRootDirectory(); goto cce96; F1b1b: $vhostTemplate = new PhpVhostTemplate($phpSite); goto Bfd3d; ceb5f: if (!(false === empty($varnishCache))) { goto de55d; } goto E1c2f; F3076: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\x2f")), "\57"); goto e4b7a; Eb0f3: $phpSiteCreator = new PhpSiteCreator($phpSite); goto c1003; C9997: goto e970c; goto e9cff; c2f6f: d3398: goto Bffc6; Fd449: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto A0dde; cce96: $phpSiteCreator->createLogrotateFile(); goto c5896; d866b: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\x2e\x25\163", $domainName); goto c2f6f; b4183: $siteEntity->setVhostTemplate($vhostTemplate); goto Ea83e; c9610: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto B6075; d1f92: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto c9e97; ae9c6: $vhostTemplate->build(); goto D739a; d375b: fe1c4: goto c340b; e5dff: $siteConstraints = $this->validator->validate($siteEntity); goto A568c; e52e3: $vhostTemplate = sprintf("\45\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto f7516; c92a5: $nodejsSiteCreator->installNodejs(); goto C362a; Ed805: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto F2fcf; cdbe6: $nodejsSite->setRegistrableDomain($registrableDomain); goto ad689; e6e5d: $siteEntity = $this->siteEntityManager->createEntity(); goto A642c; f2dd4: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto eda74; C362a: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto a9dba; e3b1d: if (!(false === empty($redirectionVhostTemplate))) { goto Dad63; } goto e52e3; ed4f2: $nodejsSiteCreator->createLogrotateFile(); goto faecc; Fb952: $nodejsSiteCreator->reloadNginxService(); goto Ee137; b8661: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto B1f06; C43f0: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto cf0ba; C26bc: $nodejsSettingsEntity->setPort($port); goto Fa586; A568c: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto e1610; B2e33: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Ebe00; a826b: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto Ead36; d2b8a: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto C0261; b2165: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto adf60; A3c74: $constraintViolationList->addAll($siteConstraints); goto E56f3; c5c6b: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto D46b2; f52da: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\x2f\56\x2e\57\x2e\56\57\x72\145\x73\x6f\165\x72\143\145\x73\x2f\x6e\147\151\x6e\170\57\166\150\x6f\x73\x74\x5f\x74\145\155\x70\154\x61\x74\145\57\162\x65\144\x69\x72\145\143\x74"); goto dc8f7; C0621: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto C646c; cf8c3: Ad4be: goto A989d; e389a: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto D0d96; Fa586: $nodejsSettingsEntity->setSite($siteEntity); goto e5dff; cf0ba: $nodejsSiteCreator->createUser(); goto a2a69; dc8f7: goto Ad4be; goto a41c8; b509d: $siteEntity->setCertificate($certificateEntity); goto Fc3ad; a41c8: D9bc7: goto ea1b0; f7516: Dad63: goto Bcf42; A3892: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto C0621; c340b: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto F0b2b; C646c: $vhostTemplate->resetProcessors(); goto B59bc; d79e9: $siteEntity->setRootDirectory($domainName); goto Ec713; faecc: $nodejsSiteCreator->createNvmDirectory(); goto c92a5; Ee137: $nodejsSiteCreator->resetPermissions(); goto A3892; aec4c: $siteEntity->setVhostTemplate($vhostTemplate); goto b8661; F2e6a: $certificateEntity->setSite($siteEntity); goto abfd9; c62c0: $csr = $csrGenerator->generate(); goto f2dd4; Cf62e: D632d: goto f699f; e8323: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto C26bc; a06a4: $this->siteEntityManager->updateEntity($siteEntity); goto Ffd8a; Ebe00: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto e54fd; Bebe8: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto Cd1d9; d9895: if (!(true === is_null($subdomain))) { goto D632d; } goto abfec; f699f: if (!(false === is_null($subdomain) && "\167\x77\167" == $subdomain)) { goto fe1c4; } goto dc91d; Bcf42: C8e65: goto aec4c; abfd9: $rsaKeyGenerator = new RsaKeyGenerator(); goto c5c6b; c9e97: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto b2165; f3cc4: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto ae9c6; D46b2: $subjectAlternativeNames = []; goto d9895; B59bc: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto D3694; e1610: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto Ae2bf; } goto C733b; Ead36: $nodejsSite->setCertificate($certificateEntity); goto Bebe8; A989d: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto e3b1d; Cd1d9: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto C43f0; dc91d: $subjectAlternativeNames[] = $registrableDomain; goto d375b; eda74: $certificateEntity->setDefaultCertificate(true); goto Ac490; ea1b0: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\56\x2e\57\x2e\x2e\x2f\x72\x65\163\x6f\165\162\143\x65\x73\57\156\147\x69\156\170\x2f\166\150\157\163\164\137\x74\x65\x6d\160\x6c\141\x74\x65\57\162\x65\x64\x69\x72\145\x63\x74\55\150\x74\164\x70\63"); goto cf8c3; Eb4dc: $siteEntity->setUserPassword($siteUserPassword); goto d79e9; D0d96: $nodejsSite->setDomainName($domainName); goto cdbe6; B1f06: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto e8323; Eb703: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto a06a4; E125a: $siteEntity->setDomainName($domainName); goto Dd922; ad689: $nodejsSite->setSubdomain($subdomain); goto a826b; Ac490: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto cdabb; Dd922: $siteEntity->setUser($siteUser); goto Eb4dc; F0b2b: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto c62c0; ebe5c: $certificateEntity = $this->certificateEntityManager->createEntity(); goto F2e6a; a9dba: $nodejsSiteCreator->createNginxVhost(); goto Fb952; C0261: throw new \Exception(implode("\x3b\40", $errorMessages)); goto F798b; e54fd: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto e6e5d; C733b: $constraintViolationList = new ConstraintViolationList(); goto A3c74; A642c: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto E125a; a2a69: $nodejsSiteCreator->createRootDirectory(); goto ed4f2; Ec713: if (!(true === is_null($subdomain) || "\x77\x77\x77" == $subdomain)) { goto C8e65; } goto bc5a1; b0d7f: $nodejsSite->setUser($siteEntity->getUser()); goto e389a; cdabb: $certificateEntity->setCsr($csr); goto Ed805; Ffd8a: return $siteEntity; goto ce234; D739a: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Eb703; E56f3: $constraintViolationList->addAll($nodejsSettingsConstraints); goto d2b8a; F798b: Ae2bf: goto ebe5c; F2fcf: $certificateEntity->setCertificate($selfSignedCertificate); goto b509d; adf60: $subdomain = $resolvedDomainName->subDomain()->toString(); goto B2e33; abfec: $subjectAlternativeNames[] = sprintf("\167\x77\x77\x2e\x25\x73", $domainName); goto Cf62e; Fc3ad: $nodejsSite = new NodejsSite(); goto b0d7f; D3694: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto f3cc4; bc5a1: if (true === isset($_ENV["\101\x50\x50\x5f\x48\124\124\120\63"]) && "\x74\162\x75\x65" === $_ENV["\x41\120\120\x5f\110\x54\x54\120\x33"]) { goto D9bc7; } goto f52da; ce234: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto eb89c; cd408: $pythonSiteCreator->writePythonVersionFile(); goto C6403; abae1: if (!(false === empty($redirectionVhostTemplate))) { goto F856b; } goto E02cf; fec52: $certificateEntity->setDefaultCertificate(true); goto e3fd5; b3d42: $csr = $csrGenerator->generate(); goto f38f3; A3f8e: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto Ac29f; c3f80: $pythonSite->setRegistrableDomain($registrableDomain); goto D04d6; B038b: $pythonSite = new PythonSite(); goto ac261; f63b1: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto c1628; C287a: $pythonSite->setCertificate($certificateEntity); goto D1db0; F6108: $vhostTemplate->resetProcessors(); goto b6c58; D0077: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto Cf900; C5ee7: $certificateEntity->setCsr($csr); goto d6058; E0540: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto c2c31; f66f4: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto Fc367; } goto d0afb; eb89c: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto E0540; E3c46: $siteEntity->setRootDirectory($domainName); goto Cadbb; e05c3: $certificateEntity->setCertificate($selfSignedCertificate); goto E5250; C87d8: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto ec19c; b7a59: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Bcf58; f38f3: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto fec52; a6d9c: $pythonSiteCreator->createLogrotateFile(); goto cd408; Abb64: $pythonSettingsEntity = new PythonSettingsEntity(); goto B5662; Ab80b: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto cc59b; b16cc: $pythonSiteCreator->resetPermissions(); goto A3f8e; B3d1a: $rsaKeyGenerator = new RsaKeyGenerator(); goto b7a59; A4051: $pythonSiteCreator->reloadNginxService(); goto b16cc; c1628: Fc367: goto e2c2f; B5662: $siteEntity->setPythonSettings($pythonSettingsEntity); goto C1b67; ec19c: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto A0116; C222e: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\x2e\x2e\x2f\56\56\57\x72\145\x73\157\165\162\143\x65\x73\x2f\x6e\x67\151\156\x78\57\x76\x68\x6f\163\164\137\x74\x65\155\160\154\x61\164\x65\x2f\x72\145\x64\151\x72\145\x63\164"); goto e7932; b87c9: $pythonSettingsEntity->setPort($port); goto e77f2; A0116: $pythonSiteCreator->createUser(); goto Ce626; e2c2f: $certificateEntity = $this->certificateEntityManager->createEntity(); goto C7c40; Ac29f: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto F6108; Ec6a6: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto b3d42; a101f: $siteEntity->setUser($siteUser); goto fddda; E5250: $siteEntity->setCertificate($certificateEntity); goto B038b; e3fd5: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto C5ee7; D04d6: $pythonSite->setSubdomain($subdomain); goto e1e83; c2c31: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Ef351; d3200: if (!(false === is_null($subdomain) && "\167\x77\167" == $subdomain)) { goto Ac7d2; } goto Ff902; Fe36e: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto e1854; E02cf: $vhostTemplate = sprintf("\45\x73\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto E44af; c69c9: c8e61: goto Defa9; Ff902: $subjectAlternativeNames[] = $registrableDomain; goto Ee2b5; ad6ac: $constraintViolationList->addAll($siteConstraints); goto C7fb1; cc59b: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto F7481; Ba23e: $siteConstraints = $this->validator->validate($siteEntity); goto B320c; fddda: $siteEntity->setUserPassword($siteUserPassword); goto E3c46; F7481: $vhostTemplate->build(); goto bc4d3; d6058: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto e05c3; E6f47: return $siteEntity; goto Ce378; e2e50: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto c0549; Ef351: $subdomain = false === empty($subdomain) ? $subdomain : null; goto e9470; Bf7ce: $subjectAlternativeNames[] = sprintf("\167\167\167\x2e\45\x73", $domainName); goto C47e4; Cf900: $siteEntity->setDomainName($domainName); goto a101f; d0afb: $constraintViolationList = new ConstraintViolationList(); goto ad6ac; Af149: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E6f47; C9284: if (!(true === is_null($subdomain))) { goto Ef2cf; } goto Bf7ce; c0549: $pythonSite->setDomainName($domainName); goto c3f80; b6c58: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Ab80b; E44af: F856b: goto b0800; ebaf8: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Ec6a6; C47e4: Ef2cf: goto d3200; e1854: $siteEntity = $this->siteEntityManager->createEntity(); goto D0077; C7c40: $certificateEntity->setSite($siteEntity); goto B3d1a; bc4d3: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto C5b13; Ef1fb: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto f63b1; A6145: $pythonSiteCreator->createNginxVhost(); goto A4051; C5b13: $this->siteEntityManager->updateEntity($siteEntity); goto Af149; ac261: $pythonSite->setUser($siteEntity->getUser()); goto e2e50; C5647: if (true === isset($_ENV["\101\x50\x50\137\x48\124\124\x50\x33"]) && "\164\162\x75\145" === $_ENV["\101\120\x50\137\110\x54\124\x50\x33"]) { goto C2d76; } goto C222e; a37cc: C2d76: goto e5dcd; C6403: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto A6145; e7932: goto c8e61; goto a37cc; e1e83: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto C287a; Cadbb: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto B6afa; } goto C5647; Bcf58: $subjectAlternativeNames = []; goto C9284; Defa9: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto abae1; C7fb1: $constraintViolationList->addAll($pythonSettingsConstraints); goto Ef1fb; C1b67: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto b87c9; Ce626: $pythonSiteCreator->createRootDirectory(); goto a6d9c; B320c: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto f66f4; D3235: $siteEntity->setVhostTemplate($vhostTemplate); goto Abb64; e5dcd: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\56\56\57\x2e\56\57\162\x65\163\x6f\165\x72\x63\x65\163\57\x6e\147\x69\156\170\57\166\x68\157\x73\164\137\164\x65\155\x70\x6c\141\x74\145\57\x72\145\x64\151\162\x65\143\164\55\x68\x74\164\x70\63"); goto c69c9; e9470: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto Fe36e; e77f2: $pythonSettingsEntity->setSite($siteEntity); goto Ba23e; D1db0: $pythonSite->setPythonSettings($pythonSettingsEntity); goto C87d8; b0800: B6afa: goto D3235; Ee2b5: Ac7d2: goto ebaf8; Ce378: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto Bb10d; e7145: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Ad299; E2dda: $this->siteEntityManager->updateEntity($siteEntity); goto d1c01; a4668: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto a6825; Ec46f: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto b66a6; Ada0f: $siteConstraints = $this->validator->validate($siteEntity); goto Bee23; b12d3: $siteEntity->setDomainName($domainName); goto e8ad6; e8ad6: $siteEntity->setUser($siteUser); goto C2a40; Bf66d: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E2dda; Bee23: if (!count($siteConstraints)) { goto c0a05; } goto F6feb; Bb8f2: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Bcf7f; da5d2: $csr = $csrGenerator->generate(); goto cc1de; e75f3: if (!(true === is_null($subdomain))) { goto da51e; } goto Dbeed; Fb399: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Fdcf5; A7a50: $staticSiteCreator->resetPermissions(); goto b0dff; F6feb: $constraintViolationList = new ConstraintViolationList(); goto Fd3e5; D9072: B294d: goto e4402; ba7ea: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\56\x2f\56\56\57\x72\145\163\x6f\x75\x72\x63\x65\x73\57\x6e\x67\x69\156\170\x2f\x76\x68\157\163\x74\x5f\164\145\x6d\160\154\x61\164\x65\57\162\x65\x64\151\x72\145\143\164\x2d\x68\164\164\160\63"); goto D6b85; f4b9b: $staticSite->setSubdomain($subdomain); goto A803e; D1586: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto de341; A803e: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto a6601; f06a6: $certificateEntity->setCertificate($selfSignedCertificate); goto fede2; A111d: $staticSiteCreator->createNginxVhost(); goto aa51c; ac6ea: if (!(true === is_null($subdomain) || "\x77\167\x77" == $subdomain)) { goto ee816; } goto dbcd0; c933c: $staticSiteCreator->createUser(); goto a748b; de341: if (!(false === empty($redirectionVhostTemplate))) { goto B294d; } goto Bb9b2; e4633: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Bf66d; Fd3e5: $constraintViolationList->addAll($siteConstraints); goto Db48f; B9ca4: $staticSite->setUser($siteEntity->getUser()); goto a4668; Cb183: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto F4963; } goto E63b6; d3928: $staticSiteCreator = new StaticSiteCreator($staticSite); goto c933c; b66a6: $vhostTemplate->resetProcessors(); goto A2f39; B48c4: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto f06a6; cc1de: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto fa86f; a6601: $staticSite->setCertificate($certificateEntity); goto e0d8b; fa86f: $certificateEntity->setDefaultCertificate(true); goto Bb8f2; ec41e: da51e: goto Cb183; Bb10d: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto E321f; F5daf: $subdomain = $resolvedDomainName->subDomain()->toString(); goto be084; Bcf7f: $certificateEntity->setCsr($csr); goto B48c4; fede2: $siteEntity->setCertificate($certificateEntity); goto B0928; Bd479: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto d21d3; B4bcd: $siteEntity->setVhostTemplate($vhostTemplate); goto Ada0f; Ad299: $certificateEntity->setSite($siteEntity); goto beff2; A2f39: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Bf69e; A6917: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto Fb399; Ca5eb: $staticSiteCreator->createIndexHtml(); goto f0690; F6fef: c0a05: goto e7145; C571b: $siteEntity->setRootDirectory($domainName); goto ac6ea; e0d8b: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto d3928; d1c01: return $siteEntity; goto Ca4f5; C2a40: $siteEntity->setUserPassword($siteUserPassword); goto C571b; b0dff: $vhostTemplate = new StaticVhostTemplate($staticSite); goto Ec46f; Dbeed: $subjectAlternativeNames[] = sprintf("\x77\x77\167\56\x25\x73", $domainName); goto ec41e; C1ecd: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto da5d2; E321f: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto F5daf; Ee34c: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto f73db; d21d3: $subjectAlternativeNames = []; goto e75f3; E63b6: $subjectAlternativeNames[] = $registrableDomain; goto c6851; Db48f: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto F9d27; Ba0ab: $staticSite->setRegistrableDomain($registrableDomain); goto f4b9b; F9d27: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto F6fef; D6b85: C4d2b: goto D1586; eb6a0: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\x2e\56\x2f\56\x2e\x2f\162\x65\x73\157\x75\162\143\x65\x73\x2f\x6e\147\151\x6e\x78\57\166\150\x6f\x73\164\x5f\164\x65\x6d\x70\x6c\141\x74\x65\x2f\162\x65\144\x69\x72\x65\143\x74"); goto e847c; Bb9b2: $vhostTemplate = sprintf("\x25\x73\45\163", $redirectionVhostTemplate, $vhostTemplate); goto D9072; f73db: $vhostTemplate->build(); goto e4633; dbcd0: if (true === isset($_ENV["\x41\x50\120\x5f\110\x54\124\120\63"]) && "\164\162\x75\x65" === $_ENV["\x41\120\x50\x5f\110\x54\x54\120\63"]) { goto D1c6c; } goto eb6a0; c9dcc: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto b12d3; b46f7: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto C1ecd; c6851: F4963: goto b46f7; a6825: $staticSite->setDomainName($domainName); goto Ba0ab; be084: $subdomain = false === empty($subdomain) ? $subdomain : null; goto A6917; beff2: $rsaKeyGenerator = new RsaKeyGenerator(); goto Bd479; e4402: ee816: goto B4bcd; e847c: goto C4d2b; goto f863f; f863f: D1c6c: goto ba7ea; aa51c: $staticSiteCreator->reloadNginxService(); goto A7a50; a748b: $staticSiteCreator->createRootDirectory(); goto Ca5b9; Ca5b9: $staticSiteCreator->createLogrotateFile(); goto Ca5eb; f0690: $staticSiteCreator->createPrivateKeyAndCertificate(); goto A111d; Fdcf5: $siteEntity = $this->siteEntityManager->createEntity(); goto c9dcc; Bf69e: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Ee34c; B0928: $staticSite = new StaticSite(); goto B9ca4; Ca4f5: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto C305a; F79e1: $siteEntity->setUserPassword($siteUserPassword); goto C19f3; b5690: $rsaKeyGenerator = new RsaKeyGenerator(); goto e28b5; e3f98: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto ac24c; Ca8b1: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto C005b; Bb8c1: $vhostTemplate->build(); goto dc222; Db9a7: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto a3dac; Eefe2: if (!(true === is_null($subdomain) || "\x77\x77\x77" == $subdomain)) { goto A429a; } goto Cf27d; A62b7: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto db48e; Edebd: $reversProxySiteCreator->resetPermissions(); goto b3bf0; B8f6f: faf65: goto b2acd; D0ad1: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto faf65; } goto D61d9; Fd2d6: return $siteEntity; goto D95e3; Bc4b8: $reversProxySiteCreator->createNginxVhost(); goto a4f11; D6cf5: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto D63cf; Bb750: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto B4291; C75ab: $siteConstraints = $this->validator->validate($siteEntity); goto c219a; e41b9: $reverseProxySite->setRegistrableDomain($registrableDomain); goto Fde2a; Cf06b: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Bb8c1; ac24c: $reverseProxySite->setDomainName($domainName); goto e41b9; caca0: $siteEntity->setCertificate($certificateEntity); goto aaa08; C469a: if (!(false === empty($redirectionVhostTemplate))) { goto Dc4fe; } goto bdf69; Fc2be: b12b3: goto D0ad1; a4f11: $reversProxySiteCreator->reloadNginxService(); goto Edebd; db48e: $certificateEntity->setCertificate($selfSignedCertificate); goto caca0; F88d3: $siteEntity->setUser($siteUser); goto F79e1; C953c: A429a: goto F86d7; A9c23: if (!(true === is_null($subdomain))) { goto b12b3; } goto F50df; a8e92: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto Eefe2; d1cda: $vhostTemplate->resetProcessors(); goto ad117; C305a: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Ba302; D63cf: throw new \Exception(implode("\73\40", $errorMessages)); goto be945; F86d7: $siteEntity->setVhostTemplate($vhostTemplate); goto C75ab; Fd185: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\x2f\x2e\56\57\56\x2e\57\162\x65\x73\157\165\162\x63\x65\163\57\x6e\x67\151\156\x78\57\x76\150\x6f\x73\164\x5f\x74\145\x6d\x70\x6c\141\164\x65\x2f\x72\145\144\x69\162\145\143\164\x2d\150\164\x74\160\63"); goto B6efd; b0cd9: $reversProxySiteCreator->createRootDirectory(); goto a0101; edf08: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f317d; c219a: if (!count($siteConstraints)) { goto D276b; } goto ddfa1; a3dac: $reverseProxySite->setCertificate($certificateEntity); goto Bb9f4; A53e6: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto f9736; e28b5: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto cbd8a; ca851: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto d1cda; D26e2: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto bf269; F8a3b: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto F41ca; f9736: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto e8c05; ddfa1: $constraintViolationList = new ConstraintViolationList(); goto B1a6b; Be16c: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Bb750; e8c05: $siteEntity = $this->siteEntityManager->createEntity(); goto Bb347; B6efd: D506e: goto Ea211; B1a6b: $constraintViolationList->addAll($siteConstraints); goto D6cf5; c5616: $csr = $csrGenerator->generate(); goto D26e2; aaa08: $reverseProxySite = new ReverseProxySite(); goto fe275; F50df: $subjectAlternativeNames[] = sprintf("\x77\167\x77\x2e\45\163", $domainName); goto Fc2be; C1afa: $certificateEntity = $this->certificateEntityManager->createEntity(); goto e1111; B4291: $reversProxySiteCreator->createUser(); goto b0cd9; ddbd7: bdfcf: goto Fd185; Bb9f4: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto Be16c; b1f79: goto D506e; goto ddbd7; b3bf0: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto ca851; ad117: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto A9b8f; Ba302: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto edf08; e6b51: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\57\56\56\57\56\56\x2f\162\x65\x73\157\x75\162\143\145\163\x2f\x6e\147\x69\156\x78\57\x76\x68\x6f\x73\164\137\164\145\x6d\160\x6c\x61\164\x65\57\x72\x65\144\x69\x72\x65\x63\164"); goto b1f79; bf269: $certificateEntity->setDefaultCertificate(true); goto F8a3b; Cf27d: if (true === isset($_ENV["\101\120\120\137\x48\x54\x54\x50\x33"]) && "\x74\162\x75\145" === $_ENV["\x41\x50\120\x5f\x48\x54\x54\120\63"]) { goto bdfcf; } goto e6b51; dc222: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Ca8b1; D61d9: $subjectAlternativeNames[] = $registrableDomain; goto B8f6f; Ea211: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto C469a; a0101: $reversProxySiteCreator->createLogrotateFile(); goto f0120; Fde2a: $reverseProxySite->setSubdomain($subdomain); goto Db9a7; fe275: $reverseProxySite->setUser($siteEntity->getUser()); goto e3f98; e1111: $certificateEntity->setSite($siteEntity); goto b5690; bdf69: $vhostTemplate = sprintf("\45\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto F519c; f0120: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto Bc4b8; C19f3: $siteEntity->setRootDirectory($domainName); goto a8e92; A3cd4: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto c5616; be945: D276b: goto C1afa; b2acd: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto A3cd4; F519c: Dc4fe: goto C953c; F41ca: $certificateEntity->setCsr($csr); goto A62b7; Bb347: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto Fb95d; C005b: $this->siteEntityManager->updateEntity($siteEntity); goto Fd2d6; A9b8f: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Cf06b; Fb95d: $siteEntity->setDomainName($domainName); goto F88d3; cbd8a: $subjectAlternativeNames = []; goto A9c23; f317d: $subdomain = false === empty($subdomain) ? $subdomain : null; goto A53e6; D95e3: } public function installedWordPressSite(Request $request) : Response { goto b06cd; bc6d5: goto f785f; goto e8f91; Dd796: return $response; goto d76cc; ef946: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto F2119; b06cd: $session = $request->getSession(); goto D0e95; E986e: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\137\x73\x69\x74\x65\163")); goto bc6d5; e8f91: e9ef2: goto ef946; D0e95: $siteCredentials = $session->get("\163\x69\164\x65\x43\162\x65\x64\145\x6e\164\x69\x61\154\x73"); goto C5a09; C5a09: if (false === empty($siteCredentials)) { goto e9ef2; } goto E986e; F2119: $response = $this->render("\x46\162\x6f\x6e\164\145\x6e\144\57\123\x69\164\x65\57\x4e\145\167\x2f\167\x6f\162\x64\x70\162\x65\163\163\x2d\151\156\x73\x74\x61\154\154\x65\144\56\x68\x74\x6d\x6c\56\164\167\151\147", ["\x73\x69\164\x65\x43\x72\x65\144\145\156\164\x69\x61\154\x73" => $siteCredentials]); goto Ba0ee; Ba0ee: return $response; goto Eae18; Eae18: f785f: goto Dd796; d76cc: } private function renderSiteCredentials(array $siteCredentials) : string { goto f907e; f907e: $renderedCredentials = ''; goto b3fed; bf8f7: return $renderedCredentials; goto c8307; b501c: dd3e5: goto bf8f7; b3fed: foreach ($siteCredentials as $section => $sectionData) { goto D44c8; ad52f: $renderedCredentials .= PHP_EOL; goto a90f4; A8b39: d7ea1: goto ad52f; a9c98: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\163\72\40\45\x73", $key, $value) . PHP_EOL; c4f32: } goto A8b39; f1d6a: $renderedCredentials .= "\55\x2d\55\x2d\55\x2d\55\55\x2d\x2d\x2d\x2d\x2d\55\x2d\55\55\x2d\x2d\x2d\55\55\55\55\55\x2d\55\55\55\55\55\55\55\x2d\55\x2d\55\x2d\x2d\55\55\x2d\55\55\x2d\x2d\55\x2d\x2d\55\55\55\55\55" . PHP_EOL; goto a9c98; a90f4: Bf8f2: goto C55cf; D44c8: $renderedCredentials .= $section . PHP_EOL; goto f1d6a; C55cf: } goto b501c; c8307: } private function getVhostTemplateEntity(string $name) : mixed { goto fdadc; d15ef: Ea949: goto Fcc28; Fcc28: return $vhostTemplateEntity; goto B92ea; Bbe14: throw new \Exception($this->translator->trans("\126\150\x6f\x73\164\x20\x54\x65\155\x70\154\141\164\145\40\x25\166\150\157\x73\x74\x54\x65\155\160\x6c\141\164\145\x25\40\x64\157\145\x73\x20\x6e\157\164\x20\145\170\151\x73\x74\x2e", ["\45\x76\150\157\163\164\x54\x65\x6d\160\154\x61\x74\x65\45" => $name])); goto d15ef; e3c6b: if (!(true === is_null($vhostTemplateEntity))) { goto Ea949; } goto Bbe14; fdadc: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto e3c6b; B92ea: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto Fd158; Fd158: $errorMessages = []; goto aca44; fd317: return $errorMessages; goto f3306; D1f47: Dbbf3: goto fd317; aca44: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\163\x3a\40\45\x73", $constraint->getPropertyPath(), $constraint->getMessage()); a98f7: } goto D1f47; f3306: } private function generateNameFromDomainName(string $domainName) : string { goto E4a87; a4118: $name = $explodedRegistrableDomain[0] ?? ''; goto c7c77; C6cad: $subdomain = $resolvedDomainName->subDomain()->toString(); goto c6d8d; c9db1: dedbb: goto c5622; a90cc: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto C6cad; c7c77: d2774: goto b8012; D718c: $name = sprintf("\x25\x73\55\45\x73", $explodedRegistrableDomain[0] ?? '', implode("\55", $explodedSubdomain)); goto c9db1; fccf1: if (!(false === empty($subdomain))) { goto dedbb; } goto F1d32; c6d8d: $explodedRegistrableDomain = explode("\x2e", $registrableDomain); goto B892b; e2d44: Ee7cc: goto a4118; B892b: if ("\167\167\167" == $subdomain) { goto Ee7cc; } goto Bc7d2; b8012: return $name; goto d289b; Bc7d2: $name = $explodedRegistrableDomain[0] ?? ''; goto fccf1; F1d32: $explodedSubdomain = explode("\x2e", $subdomain); goto D718c; c5622: goto d2774; goto e2d44; E4a87: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto a90cc; d289b: } private function getUniqueDatabaseName(string $databaseName) : string { goto f8405; a441b: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto E2d1b; e3acf: ebe44: goto a1d8f; B8c4a: if (true === $databaseExists) { goto Cb485; } goto f1ea9; f8405: $uniqueDatabaseName = $databaseName; goto Eda3a; e6d3f: Cb485: goto Cdf8a; Eda3a: if (!(strlen($uniqueDatabaseName) <= 3)) { goto ebe44; } goto Abd60; f3979: $databaseExists = in_array($uniqueDatabaseName, $databases); goto f99bf; f1ea9: f6608: goto B063c; Cdf8a: if (!(0 < $i)) { goto d1a35; } goto F42e2; E2d1b: $databases = $databaseConnection->getDatabases(); goto e6d3f; Abd60: $uniqueDatabaseName = sprintf("\x25\163\x2d\x64\x62", $uniqueDatabaseName); goto e3acf; f99bf: $i++; goto B8c4a; b6d7c: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto a441b; F42e2: $uniqueDatabaseName = sprintf("\x25\163\55\x25\x73", $databaseName, $i); goto F0b65; a1d8f: $i = 0; goto b6d7c; F0b65: d1a35: goto f3979; B063c: return $uniqueDatabaseName; goto ce327; ce327: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto D6dd1; c1afd: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto ff23d; cd173: C1024: goto e7b87; e36d7: $uniqueDatabaseUserName = sprintf("\x25\x73\x2d\45\x73", $databaseUserName, $i); goto C4d17; C0042: if (!(0 < $i)) { goto a807f; } goto e36d7; b1d65: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto C9aeb; C4d17: a807f: goto b1d65; D6dd1: $uniqueDatabaseUserName = $databaseUserName; goto aa14d; ab127: if (false === is_null($databaseUserEntity)) { goto dd2c0; } goto C704e; C704e: feed5: goto c1afd; C0e44: dd2c0: goto C0042; e7b87: $i = 0; goto C0e44; C9aeb: $i++; goto ab127; aa14d: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto C1024; } goto d379c; ff23d: return $uniqueDatabaseUserName; goto c7643; d379c: $uniqueDatabaseUserName = sprintf("\45\163\x2d\x64\x62", $uniqueDatabaseUserName); goto cd173; c7643: } private function hasPermissions() : bool { goto A322e; be312: return false; goto Ca4bb; ab6d8: return true; goto E2b37; A322e: $user = $this->getUser(); goto aa663; aa663: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto C51e3; } goto ab6d8; E2b37: C51e3: goto be312; Ca4bb: } }
